#[repr(i32)]pub enum AccountType {
Invalid = 0,
Gmail = 1,
}Variants
Implementations
Sourceimpl AccountType
impl AccountType
Sourceimpl AccountType
impl AccountType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.