pub struct Account {
pub key: String,
pub name: String,
pub type: i32,
pub scopes: Vec<i32>,
pub data: HashMap<String, String>,
}Fields
key: Stringname: Stringtype: i32scopes: Vec<i32>data: HashMap<String, String>Implementations
Sourceimpl Account
impl Account
Sourcepub fn type(&self) -> AccountType
pub fn type(&self) -> AccountType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: AccountType)
pub fn set_type(&mut self, value: AccountType)
Sets type to the provided enum value.
Sourcepub fn scopes(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<AccountScope>>
pub fn scopes( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<AccountScope>>
Returns an iterator which yields the valid enum values contained in scopes.
Sourcepub fn push_scopes(&mut self, value: AccountScope)
pub fn push_scopes(&mut self, value: AccountScope)
Appends the provided enum value to scopes.