pub struct DraftEmail {
pub account: Option<Reference>,
pub in_reply_to: Option<Reference>,
pub to: Vec<Contact>,
pub cc: Vec<Contact>,
pub bcc: Vec<Contact>,
pub subject: String,
pub parts: Vec<EmailPart>,
pub attachments: Vec<EmailAttachment>,
pub sending_date: Option<Timestamp>,
pub sent_date: Option<Timestamp>,
}Fields
account: Option<Reference>in_reply_to: Option<Reference>to: Vec<Contact>cc: Vec<Contact>bcc: Vec<Contact>subject: Stringparts: Vec<EmailPart>attachments: Vec<EmailAttachment>sending_date: Option<Timestamp>sent_date: Option<Timestamp>Trait Implementations
Sourceimpl Clone for DraftEmail
impl Clone for DraftEmail
Sourcefn clone(&self) -> DraftEmail
fn clone(&self) -> DraftEmail
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DraftEmail
impl Debug for DraftEmail
Sourceimpl Default for DraftEmail
impl Default for DraftEmail
Sourceimpl Message for DraftEmail
impl Message for DraftEmail
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl NamedMessage for DraftEmail
impl NamedMessage for DraftEmail
Sourceimpl PartialEq for DraftEmail
impl PartialEq for DraftEmail
impl StructuralPartialEq for DraftEmail